@@ -1,6 +1,6 @@
-from .conditions import EQ, LT, GT, NEQ, LTE, GTE, IN
 from .s3access import S3Access
 from .s3path import S3Path
+from .sql import EQ, LT, GT, NEQ, LTE, GTE, IN, AND, OR
 
 __all__ = [
     'S3Access',
@@ -13,4 +13,6 @@ __all__ = [
     'LTE',
     'GTE',
     'IN',
+    'AND',
+    'OR',
 ]
